@@ -15,7 +15,7 @@ use Exporter;
 use Term::ANSIColor qw(:constants);
 use Term::ANSIScreen qw(:cursor);
 
-our $VERSION = '1.3500';
+our $VERSION = '1.3501';
 
 our @EXPORT_OK = qw(einfo eerror ewarn ebegin eend eindent eoutdent einfon edie edo);
 our %EXPORT_TAGS = (all=>[@EXPORT_OK]);
@@ -112,14 +112,15 @@ sub edo($&) {
     ebegin $begin_msg;
     my ($cr, @cr);
 
-    my $r = eval { if( wantarray ) { @cr = $code->() } else { $cr = $code->() } 1 };
+    my $wa = wantarray;
+    my $r = eval { if( $wa ) { @cr = $code->() } else { $cr = $code->() } 1 };
     edie $@ unless $r;
 
     eoutdent if $do_depth>1;
     $do_depth --;
     eend 1;
 
-    return @cr if wantarray;
+    return @cr if $wa;
     return $cr;
 }
 
